<?php

namespace Drupal\tome\Commands;

use Drupal\Core\Config\StorageInterface;
use Drupal\tome\ContentIndexerTrait;
use Drupal\tome\TomeHelper;
use Drush\Commands\DrushCommands;

/**
 * Contains deprecated commands for keeping dev users from going insane.
 */
class DeprecatedCommands extends DrushCommands {

  use ContentIndexerTrait;

  /**
   * The target content storage.
   *
   * @var \Drupal\Core\Config\StorageInterface
   */
  protected $contentStorage;

  /**
   * Constructs an DeprecatedCommands instance.
   *
   * @param \Drupal\Core\Config\StorageInterface $content_storage
   *   The content storage.
   */
  public function __construct(StorageInterface $content_storage) {
    $this->contentStorage = $content_storage;
  }

  /**
   * Builds an index file from the source files.
   *
   * Note: Will be removed by alpha1's release!
   *
   * @command tome:temp-build-index
   *
   * @deprecated
   */
  public function tempBuildIndex() {
    $this->io()->comment('Note that this command will be removed by alpha1. The index should automatically be built on export and sync going forward.');
    $names = $this->contentStorage->listAll();
    $index = [];
    foreach ($names as $name) {
      $contents = $this->contentStorage->read($name);
      $dependencies = [];
      foreach ($contents as $field => $values) {
        foreach ($values as $value) {
          if (isset($value['target_type']) && isset($value['target_uuid'])) {
            $dependencies[] = TomeHelper::getContentNameFromParts($value['target_type'], $value['target_uuid']);
          }
        }
        list($entity_type_id, $uuid, $langcode) = TomeHelper::getPartsFromContentName($name);
        if ($langcode) {
          $dependency = TomeHelper::getContentNameFromParts($entity_type_id, $uuid);
          $dependencies[] = $dependency;
        }
      }
      $dependencies = array_values(array_unique($dependencies));
      $index[$name] = $dependencies;
      $destination = $this->getContentIndexFilePath();
      $directory = dirname($destination);
      file_prepare_directory($directory, FILE_CREATE_DIRECTORY);
      file_put_contents($destination, json_encode($index, JSON_PRETTY_PRINT));
    }
    $this->io()->success('Rebuilt the index.');
  }

}
