<?php

namespace Drupal\tome\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Wraps an array of paths that will be processed by the static generator.
 */
class CollectPathsEvent extends Event {

  /**
   * An array of paths.
   *
   * @var array
   */
  protected $paths;

  /**
   * Constructs a CollectPathsEvent object.
   *
   * @param array $paths
   *   An array of paths.
   */
  public function __construct(array $paths) {
    $this->paths = $paths;
  }

  /**
   * Gets the paths.
   *
   * @return array
   *   An array of paths.
   */
  public function getPaths() {
    return $this->paths;
  }

  /**
   * Adds a single path.
   *
   * @param string $path
   *   A path to add.
   */
  public function addPath($path) {
    $this->paths[] = $path;
  }

  /**
   * Adds multiple paths.
   *
   * @param array $paths
   *   An array of paths.
   */
  public function addPaths(array $paths) {
    $this->paths = array_merge($this->paths, $paths);
  }

  /**
   * Replaces all paths.
   *
   * @param array $paths
   *   An array of paths.
   */
  public function replacePaths(array $paths) {
    $this->paths = $paths;
  }

}
