<?php

namespace Drupal\tome;

/**
 * Provides an interface for the static generator.
 */
interface StaticGeneratorInterface {

  /**
   * Gets all public-facing paths for the site.
   *
   * Entity paths will be returned in the format
   * "_entity:entity_type_id:langcode:entity_id" and should be loaded by the
   * caller using a batch process.
   *
   * @param bool $partial
   *   Whether only paths that are not already generated should be returned.
   *
   * @return string[]
   *   An array of paths.
   */
  public function getPaths($partial = FALSE);

  /**
   * Requests and exports a given path.
   *
   * This method should only be called for paths that need a Drupal bootstrap.
   *
   * Note that calling this method multiple times in one bootstrap may have
   * result in improper renders - it's recommended that this is called once
   * per request.
   *
   * @param string $path
   *   A path to export, or an entity to load and export in the format
   *   "_entity:entity_type_id:langcode:entity_id".
   * @param bool $partial
   *   Whether only paths that are not already generated should be returned.
   *
   * @return string[]
   *   An array of paths that should be passed to ::exportPaths.
   */
  public function requestPath($path, $partial = FALSE);

  /**
   * Exports multiple paths.
   *
   * If a path is a file that already exists, it will be immediately copied. If
   * a path needs to be fetched in a new request, it will be returned.
   *
   * @param string[] $paths
   *   An array of paths to export.
   *
   * @return string[]
   *   An array of paths that need to be fetched in new requests. Usually these
   *   are image style derivatives.
   */
  public function exportPaths(array $paths);

  /**
   * Gets the static directory.
   *
   * @return string
   *   The static directory.
   */
  public function getStaticDirectory();

}
