<?php

namespace Drupal\tome;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderInterface;
use Drupal\tome\EventSubscriber\BookEventSubscriber;
use Drupal\tome\EventSubscriber\LanguageConfigEventSubscriber;
use Drupal\tome\EventSubscriber\LanguagePathSubscriber;
use Drupal\tome\PageCache\RequestPolicy\DynamicRequestPolicy;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Registers services in the container.
 */
class TomeServiceProvider implements ServiceProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function register(ContainerBuilder $container) {
    $modules = $container->getParameter('container.modules');
    if (isset($modules['language'])) {
      $container->register('tome.language_config_event_subscriber', LanguageConfigEventSubscriber::class)
        ->addTag('event_subscriber')
        ->addArgument(new Reference('config.storage.sync'));
      $container->register('tome.language_path_subscriber', LanguagePathSubscriber::class)
        ->addTag('event_subscriber')
        ->addArgument(new Reference('config.factory'))
        ->addArgument(new Reference('language_manager'));
    }
    if (isset($modules['book'])) {
      $container->register('tome.book_event_subscriber', BookEventSubscriber::class)
        ->addTag('event_subscriber')
        ->addArgument(new Reference('database'))
        ->addArgument(new Reference('entity_type.manager'));
    }
    if (isset($modules['dynamic_page_cache'])) {
      $container->register('tome.dynamic_page_cache_request_policy', DynamicRequestPolicy::class)
        ->setDecoratedService('dynamic_page_cache_request_policy');
    }
  }

}
