<?php

namespace Drupal\Tests\tome\Kernel;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\tome\TomeHelper;

/**
 * Tests that exports are updated when fields are deleted.
 *
 * @group tome
 */
class FieldDeletionTest extends TestBase {

  /**
   * @covers \Drupal\tome\Exporter::exportContent
   */
  public function testDeleteField() {
    /** @var \Drupal\Core\Config\StorageInterface $storage */
    $storage = \Drupal::service('tome.storage.content');

    $field_config = node_add_body_field(NodeType::load('article'));
    node_add_body_field(NodeType::load('page'));

    $article = Node::create([
      'type' => 'article',
      'title' => 'My article',
    ]);
    $article->save();

    $page = Node::create([
      'type' => 'page',
      'title' => 'My page',
    ]);
    $page->save();

    $data = $storage->read(TomeHelper::getContentName($article));
    $this->assertArrayHasKey('body', $data);

    $data = $storage->read(TomeHelper::getContentName($page));
    $this->assertArrayHasKey('body', $data);

    $field_config->delete();

    $data = $storage->read(TomeHelper::getContentName($article));
    $this->assertArrayNotHasKey('body', $data);

    $data = $storage->read(TomeHelper::getContentName($page));
    $this->assertArrayHasKey('body', $data);

    FieldStorageConfig::loadByName('node', 'body')->delete();

    $data = $storage->read(TomeHelper::getContentName($page));
    $this->assertArrayNotHasKey('body', $data);
  }

}
